##  Creating an Automation with a Script
Follow these steps:
  1. Start creating an automation by specifying a triggering event and conditions. For details, see [Creating an Automation](https://help.sap.com/docs/leanix/ea/automations?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758d6af7a441014b829a7547e83bfd4__creating_an_automation).
  2. Under Then, select Run Script as an action, then click New Script.
![Selecting 'Run Script' Action in an Automation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio9c9146559ccb41f7a45b57e94c4a61af_LowRes.png)
Selecting "Run Script" Action in an Automation
  3. In the script editor, define the script logic, then save the script.
  4. Add more actions to the automation if needed.
  5. Save the automation.
